Package: AStream
Type: Package
Title: AStream
Version: 2.0
Date: 2013-12-01
Author: A.Alonso, A.Julia and S.Marsal - Grup de Recerca de Reumatologia (IRHUVH)
Maintainer: <bioinformatics@urr.cat>
Depends: multtest, plotrix
Suggests: faahKO, xcms
Description: Metabolite profiling using identification of isotopes, adducts and fragments.
License: GPL (>=2)
URL: http://www.urr.cat
LazyLoad: no
Packaged: 2014-03-12 11:51:55 UTC; aalonso
Encoding: latin1
