xcms.import <-
function(object){
class    <- object@phenoData
names    <- labels(object@phenoData)[[1]]
values   <- groupval(object,"medret","into")
groupmat <- groups(object)
data     <- cbind(name = groupnames(object), groupmat, values)
data     <- data[,c(2,5,(1+ncol(data)-length(names)):ncol(data))]
data     <-data.frame(data,row.names=1:dim(data)[1])
return(list(data = data, class = class))
}
