compute.count.stats <-
function(features){

i       <- setdiff(1:length(features$class$class),features$outliers)
class   <- features$class$class[i]
classes <- levels(class)
if (length(classes)!=2) return(0)
counts  <- features$data

group1  <- which(class==classes[1]) 
group2  <- which(class==classes[2])
m1      <- apply(counts[,group1],1,mean)
m2      <- apply(counts[,group2],1,mean)
tf      <- m2 / m1
tv      <- counts[,c(group1,group2)]
tl      <- c(rep(0,length(group1)),rep(1,length(group2)))
ts      <- mt.teststat(tv,tl)
pvalues <- pvalcc(tv,tl,ts)
return(pvalues)
}
