\name{web.report}
\alias{web.report}
\title{WEB REPORT}
\description{Generates a web report}
\usage{
astream.annotate(ftlist, results, dataset.name = "", output.dir = "web_report")
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ftlist }{ list returned by \code{\link{isotope.search}}.}
  \item{results }{ matrix returned by \code{\link{adduct.search}}.}
  \item{dataset.name }{ Dataset name.}
  \item{output.dir}{ Folder that will be created for the web report.}
}
\details{
}
\value{
}
\author{A.Alonso, et al. Grup de Recerca de Reumatologia 2010, bioinformatics@urr.cat.}
\seealso{\code{\link{xcms.import}}, \code{\link{data.norm}}, \code{\link{isotope.search}}, \code{\link{adduct.search}}, \code{\link{plotcompound}}.}