\name{compute.count.stats}
\alias{compute.count.stats}
\title{internal function}
\description{internal function}
\usage{
compute.count.stats(features)
}
\arguments{
  \item{features}{NA}
}
\details{NA}
\value{NA}
