\name{hmdb}
\alias{hmdb}
\docType{data}
\title{
Metabolites imported from the HMDB 
}
\description{
List of metabolites imported from the Human Metabolome Database.
}
\usage{data(hmdb)}
\format{
  A data frame with 41488 observations on the following 5 variables.
  \describe{
    \item{\code{accession}}{accession names}
    \item{\code{mass}}{monoisotopic masses}
    \item{\code{name}}{compound names}
    \item{\code{biofluid}}{biofluid locations}
    \item{\code{tissue}}{tissue locations}
  }
}
\details{
%%  ~~ If necessary, more details than the __description__ above ~~
}
\source{
http://www.hmdb.ca
}