\name{adduct.list}
\alias{adduct.list}
\title{Default adduct list}
\description{Provides a default adducts list based on the selected ionization mode.}
\usage{
adduct.list(mode = "+")
}
\arguments{
  \item{mode }{ ionization mode.}
}
\details{
}
\value{
  \item{labels }{ adduct labels.}
  \item{masses }{ adduct masses.}
}
\author{A.Alonso, et al. Grup de Recerca de Reumatologia 2010, bioinformatics@urr.cat.}