\name{pvalcc}
\alias{pvalcc}
\title{internal}
\description{internal}
\usage{
pvalcc(X, classlabel, teststat)
}
\arguments{
  \item{X}{X}
  \item{classlabel}{classlabel}
  \item{teststat}{teststat}
}
\details{internal}
\value{internal}
