\name{plotcompound}
\alias{plotcompound}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Plot feature and related isotopic/adduct features.}
\description{Plot a feature and related isotopic/adduct features}
\usage{
plotcompound(num, ftlist, results)
}
\arguments{
  \item{num}{feature id to be plotted}
  \item{ftlist}{AStream isotope.search() output}
  \item{results}{Astream adduct.search() output}
}
\details{Plot a feature and related isotopic/adduct features}
\value{A plot.}
\author{A.Alonso, et al. Grup de Recerca de Reumatologia 2010, bioinformatics@urr.cat.}
\seealso{\code{\link{data.norm}}, \code{\link{isotope.search}}, \code{\link{printresults}}, \code{\link{plotcompound}}.}
